.. _user_guide_encoders_index:

Column-level feature extraction
===============================

Skrub provides various transformers that help with feature engineering numeric,
datetime and categorical data. The encoders covered in this section convert the
raw features found in an input dataframe into numeric features that can be used
directly by machine learning models.

.. include:: includes/big_toc_css.rst

.. toctree::
   :maxdepth: 3

   modules/column_level_featurizing/feature_engineering_categorical
   modules/column_level_featurizing/feature_engineering_datetimes
   modules/column_level_featurizing/robust_scaling
